# packages/src/nyc_records_db/migrations/env.py
"""Alembic migration environment for NYC Records Database.

This module configures the Alembic migration environment:
- Sets up database connection
- Imports model metadata
- Configures migration context
- Handles online/offline migrations

Usage:
    This file is used by Alembic CLI to run migrations:
    alembic upgrade head
    alembic revision --autogenerate -m "description"
"""

from logging.config import fileConfig

from alembic import context
from sqlalchemy import engine_from_config, pool

from nyc_records_db.config.settings import DatabaseSettings
from nyc_records_db.models.base import Base

# Load Alembic config
config = context.config
settings = DatabaseSettings()

# Set SQLAlchemy URL in Alembic config
config.set_main_option("sqlalchemy.url", settings.DATABASE_URL)

# Load logging configuration
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

target_metadata = Base.metadata


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode."""
    url = config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations_online() -> None:
    """Run migrations in 'online' mode."""
    connectable = engine_from_config(
        config.get_section(config.config_ini_section),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(connection=connection, target_metadata=target_metadata)

        with context.begin_transaction():
            context.run_migrations()


if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()
